@@ -7,6 +7,7 @@ package String::Print;
 
 use warnings;
 use strict;
+use utf8;
 
 #use Log::Report::Optional 'log-report';
 
@@ -18,16 +19,25 @@ use POSIX             qw/strftime/;
 use Scalar::Util      qw/blessed reftype/;
 
 my @default_modifiers   = (
-	qr/\% ?\S+/     => \&_modif_format,
-	qr/BYTES\b/     => \&_modif_bytes,
-	qr/HTML\b/      => \&_modif_html,
-	qr/YEAR\b/      => \&_modif_year,
-	qr/DT\([^)]*\)/ => \&_modif_dt,
-	qr/DT\b/        => \&_modif_dt,
-	qr/DATE\b/      => \&_modif_date,
-	qr/TIME\b/      => \&_modif_time,
-	qr/\=/          => \&_modif_name,
-	qr!//(?:\"[^"]*\"|\'[^']*\'|\w+)! => \&_modif_undef,
+	qr/\% ?\S+/      => \&_modif_format,
+	qr/BYTES\b/      => \&_modif_bytes,
+	qr/HTML\b/       => \&_modif_html,
+	qr/YEAR\b/       => \&_modif_year,
+	qr/DT\([^)]*\)/  => \&_modif_dt,
+	qr/DT\b/         => \&_modif_dt,
+	qr/DATE\b/       => \&_modif_date,
+	qr/TIME\b/       => \&_modif_time,
+	qr/\=/           => \&_modif_name,
+	qr!CHOP\([0-9]+(?:\,?[^)]*)\)|CHOP\b! => \&_modif_chop,
+	qr!EL\([0-9]+(?:\,?[^)]*)\)|EL\b!     => \&_modif_ellipsis,
+	qr!//(?:\"[^"]*\"|\'[^']*\'|\w+)!     => \&_modif_undef,
+);
+
+my %defaults = (
+	CHOP   => +{ width => 20, head => '[', units => '', tail => ']' },
+	DT     => +{ standard => 'FT' },
+	EL     => +{ width => 20, replace => '⋯ '},
+	FORMAT => +{ thousands => '' },
 );
 
 my %default_serializers = (
@@ -58,22 +68,25 @@ String::Print - printf alternative
 
   use String::Print;           # simpelest way
   use String::Print qw/printi printp/, %config;
-  printi 'age {years}', years => 12;
+
+  printi 'age {years}', years => 12;   # to STDOUT
+  my $s = sprinti 'age {years}', years => 12;  # in variable
 
   # interpolation of arrays and hashes (serializers)
   printi 'price-list: {prices}', prices => \@p, _join => "+";
-  printi 'dump: {c}', c => \%config;
+  printi 'dump: {c}', c => \%data;
 
   # same with positional parameters
   printp 'age %d", 12;
   printp 'price-list: %.2f', \@prices;
   printp 'dump: %s', \%settings;
+  my $s = sprintp 'age %d", 12;
 
   # modifiers
   printi 'price: {price%.2f}', price => 3.14 * EURO;
 
   # [0.91] more complex interpolation names
-  printi 'filename: {c.filename}', c => \%config;
+  printi 'filename: {c.filename}', c => \%data;
   printi 'username: {user.name}', user => $user_object;
   printi 'price: {product.price €}', product => $db->product(3);
 
@@ -83,6 +96,8 @@ String::Print - printf alternative
   my $f = String::Print->new(%config);
   $f->printi('age {years}', years => 12);
   $f->printp('age %d', 12);
+  my $s = $f->sprinti('age {y}', y => 12);
+  my $s = $f->sprintp('age %d', 12);
 
   ### via Log::Report's __* functions (optional translation)
 
@@ -125,6 +140,10 @@ object has some benefits.
 
 =section Constructors
 
+When you use this package with functions, then you do not call the
+constructor explicitly.  In that case, these M<new()> parameters are
+added to the C<<use String::Print>> line.
+
 =c_method new %options
 The %options of the constructure configure processing options.
 
@@ -142,7 +161,8 @@ How to serialize data elements.
 =default encode_for undef
 [0.91] The format string and the inserted values will get encoded according to
 some syntax rules.  Function C<encode_entities()> provided by HTML::Entities
-is used when you specify the predefined string C<HTML>.  See M<encodeFor()>.
+is used when you specify the predefined string C<HTML>.  See M<encodeFor()>
+and L</Output encoding>.
 
 =option  missing_key CODE
 =default missing_key <warning>
@@ -150,6 +170,11 @@ is used when you specify the predefined string C<HTML>.  See M<encodeFor()>.
 from the parameter list.  In that case, a warning is produced and undef
 inserted.  May can overrule that behavior.
 
+=option  defaults   \%defaults
+=default defaults   C<see modifier docs>
+[1.00] change the defaults for some modifiers.  This is a map of
+modifier name to HASH with modifier specific settings.
+
 =examples
 
   my $f = String::Print->new(
@@ -162,7 +187,7 @@ inserted.  May can overrule that behavior.
   $f->printi("count: {c}", c => undef);      # count: -
 =cut
 
-sub new(@) { my $class = shift; (bless {}, $class)->init( {@_} ) }
+sub new(@) { my $class = shift; (bless {}, $class)->init( +{@_} ) }
 
 sub init($)
 {	my ($self, $args) = @_;
@@ -175,6 +200,9 @@ sub init($)
 	my $s    = $args->{serializers} || {};
 	my $seri = $self->{SP_seri} = +{ %default_serializers, (ref $s eq 'ARRAY' ? @$s : %$s) };
 
+	$self->{SP_defs} = +{ %defaults };  # the HASHes get copied when changed.
+	$self->setDefaults($args->{defaults}) if $args->{defaults};
+
 	$self->encodeFor($args->{encode_for});
 	$self->{SP_missing} = $args->{missing_key} || \&_reportMissingKey;
 	$self;
@@ -221,8 +249,11 @@ See section L</"Interpolation: Modifiers"> about the details.
 
 sub addModifiers(@) { my $s = shift; unshift @{$s->{SP_modif}}, @_ }
 
-=method encodeFor HASH|undef|($predefined, %overrule)
-[0.91] Enable/define the output encoding.
+=method encodeFor \%settings|undef|($predefined, %overrule)
+[0.91] Enable/define the output encoding.  The %settings contain the C<encoding>
+CODE and the tag name patterns to C<exclude> from encoding.  Output for C<HTML>
+is $predefined, but you may %overrule its settings.
+
 Read section L</"Output encoding"> about the details.
 =cut
 
@@ -236,8 +267,7 @@ sub encodeFor($)
 	{	%def = %$type;
 	}
 	else
-	{	my $def = $predefined_encodings{$type}
-			or die "ERROR: unknown output encoding type $type\n";
+	{	my $def = $predefined_encodings{$type} or die "ERROR: unknown output encoding type $type\n";
 		%def = (%$def, @_);
 	}
 
@@ -250,27 +280,86 @@ sub encodeFor($)
 	$self->{SP_enc} = \%def;
 }
 
-#XXX
-# OODoc does not like it when we have methods and functions with the same name.
+=method setDefaults \%defaults|@defaults
+[1.00] Set the defaults for modifiers, either with a HASH where the key modifier name
+maps to a HASH of settings, or a list of PAIRS.
+
+When using the methods in OO style , you can change the defaults at any time.  For
+functional style, the object is hidden.
+
+=example setting defaults
+
+  $sp->setDefaults(EL => {width => 30}, CHOP => {width => 10});
+
+  my %defs = (EL => {width => 30}, CHOP => {width => 10});
+  $sp->setDefaults(\%defs);
+
+=cut
+
+sub setDefaults(@)
+{	my $self    = shift;
+	my $default = $self->{SP_defs};
+
+	my @set = @_==1 && ref $_[0] eq 'HASH' ? %{$_[0]} : @_;
+	while(@set)
+	{	my ($modif, $defs) = (shift @set, shift @set);
+		my $was = $defaults{$modif} or die "No defaults available for $modif.";
+		$default->{$modif} = +{ %$was, %$defs };
+	}
+
+	$self;
+}
+
+=method defaults $modifier
+[1.00] Returns the current defaults for the $modifier.
+
+=example getting defaults for a modifier
+  my $def = $sp->defaults('EL');
+  say "Default max width is ", $def->{width};
+=cut
+
+sub defaults($) { $_[0]->{SP_defs}{$_[1]} }
 
 #--------------------
+#XXX OODoc does not like it when we have methods and functions with the same name.
+
 =section Printing
 
-The following are provided as method and as function.  You find their
-explanation further down on this page.
+The following are provided both as method and as function.  The function
+version is explained further down on this page, because it reads a bit
+easier, but the object version is most flexible.
 
-  $obj->printi([$fh], $format, %data|\%data);
-  $obj->printp([$fh], $format, @params, %options);
-  my $s = $obj->sprinti($format, %data|\%data);
-  my $s = $obj->sprintp($format, @params, %options);
+  my $sp = String::Print->new;
+  $sp->printi([$fh], $format, %data|\%data);        # see M<printi()>
+  $sp->printp([$fh], $format, @params, %options);   # see M<printp()>
+  my $s = $sp->sprinti($format, %data|\%data);      # see M<sprinti()>
+  my $s = $sp->sprintp($format, @params, %options); # see M<sprintp()>
+
+=examples
+
+  use String::Print 'oo';    # do not import the functions
+
+  my $sp = String::Print->new(
+    modifiers   => [ EUR   => sub {sprintf "%5.2f e", $_[0]} ],
+    serializers => [ UNDEF => sub {'-'} ],
+    defaults    => [ DT => { standard => 'ISO' } ],
+  );
+
+  $sp->printi("price: {p EUR}", p => 3.1415); # price: ␣␣3.14 e
+  $sp->printi("count: {c}", c => undef);      # count: -
+  my $s = $sp->sprinti("price: {p EUR}", p => 7); # output in $s
 
 =cut
 
 #--------------------
 =chapter FUNCTIONS
 
-The functional interface creates a hidden object.  You may import any of
-these functions explicitly, or all together by not specifying the names.
+The functional interface creates a hidden C<String::Print> object, which is
+reused in the whole active package.  Seperate packages will use different
+hidden objects.
+
+You may import any of these functions explicitly, or all together by
+not specifying the names.
 
 =examples
 
@@ -279,10 +368,12 @@ these functions explicitly, or all together by not specifying the names.
 
   use String::Print 'printi',   # only printi
     modifiers   => [ EUR   => sub {sprintf "%5.2f e", $_[0]} ],
-    serializers => [ UNDEF => sub {'-'} ];
+    serializers => [ UNDEF => sub {'-'} ],
+    defaults    => [ DT => { standard => 'ISO' } ];
 
   printi "price: {p EUR}", p => 3.1415; # price: ␣␣3.14 e
   printi "count: {c}", c => undef;      # count: -
+  my $s = sprinti "price: {p EUR}", p => 7;  # output in $s
 
 =function sprinti $format, %data|\%data|OBJECT, %options
 The $format refers to some string, maybe the result of a translation.
@@ -475,7 +566,7 @@ sub _modif_format_s($$$$$)
 sub _modif_format_d($$$$)
 {	my ($value, $padding, $max, $sep) = @_;
 	my $d = sprintf "%d", $value;   # what perl usually does with floats etc
-	my $v = reverse(reverse($d) =~ s/([0-9][0-9][0-9])/$1$sep/gr);
+	my $v = length $sep ? reverse(reverse($d) =~ s/([0-9][0-9][0-9])/$1$sep/gr) : $d;
 	$v =~ s/^\.//;
 
 	if($d !~ /^\-/)
@@ -488,6 +579,7 @@ sub _modif_format_d($$$$)
 
 	    $pad <= 0       ? $v 
 	  : $padding eq '-' ? $v . (' ' x $pad)
+	  : $padding eq '0' ? ('0' x $pad) . $v
 	  : $padding eq ''  ? (' ' x $pad) . $v
 	  :   $v;
 }
@@ -496,6 +588,8 @@ sub _modif_format($$$$)
 {	my ($self, $format, $value, $args) = @_;
 	defined $value && length $value or return undef;
 
+	my $defaults = $self->defaults('FORMAT');
+
 	use locale;
 	if(ref $value eq 'ARRAY')
 	{	@$value or return '(none)';
@@ -507,7 +601,7 @@ sub _modif_format($$$$)
 	}
 
 	  $format =~ m/^\%(\-?)([0-9]*)(?:\.([0-9]*))?([sS])$/ ? _modif_format_s($value, $1, $2, $3, $4)
-	: $format =~ m/^\%([+\ \-]?)([0-9]*)([_,.])d$/ ? _modif_format_d($value, $1, $2, $3)
+	: $format =~ m/^\%([+\ \-0]?)([0-9]*)([_,.])?d$/ ? _modif_format_d($value, $1, $2, $3 // $defaults->{thousands})
 	:    return sprintf $format, $value;   # simple: standard perl sprintf()
 }
 
@@ -549,7 +643,12 @@ my %dt_format = (
 
 sub _modif_year($$$)
 {	my ($self, $format, $value, $args) = @_;
-	defined $value && length $value or return undef;
+	defined $value or return undef;
+
+	blessed $value && $value->isa('DateTime')
+		and return $value->year;
+
+	length $value or return undef;
 
 	return $1
 		if $value =~ /^\s*([0-9]{4})\s*$/ && $1 < 2200;
@@ -562,7 +661,12 @@ sub _modif_year($$$)
 
 sub _modif_date($$$)
 {	my ($self, $format, $value, $args) = @_;
-	defined $value && length $value or return undef;
+	defined $value or return undef;
+
+	blessed $value && $value->isa('DateTime')
+		and return $value->ymd;
+
+	length $value or return undef;
 
 	return sprintf("%4d-%02d-%02d", $1, $2, $3)
 		if $value =~ m!^\s*([0-9]{4})[:/.-]([0-9]?[0-9])[:/.-]([0-9]?[0-9])\s*$!
@@ -576,7 +680,12 @@ sub _modif_date($$$)
 
 sub _modif_time($$$)
 {	my ($self, $format, $value, $args) = @_;
-	defined $value && length $value or return undef;
+	defined $value or return undef;
+
+	blessed $value && $value->isa('DateTime')
+		and return $value->hms;
+
+	length $value or return undef;
 
 	return sprintf "%02d:%02d:%02d", $1, $2, $3||0
 		if $value =~ m!^\s*(0?[0-9]|1[0-9]|2[0-3])\:([0-5]?[0-9])(?:\:([0-5]?[0-9]))?\s*$!
@@ -590,10 +699,17 @@ sub _modif_time($$$)
 
 sub _modif_dt($$$)
 {	my ($self, $format, $value, $args) = @_;
-	defined $value && length $value or return undef;
+	defined $value or return undef;
 
-	my $kind    = ($format =~ m/DT\(([^)]*)\)/ ? $1 : undef) || 'FT';
-	my $pattern = $dt_format{$kind}
+	blessed $value && $value->isa('DateTime')
+		and $value = $value->epoch;
+
+	length $value or return undef;
+
+	my $defaults = $self->defaults('DT');
+	my $kind     = ($format =~ m/^DT\(([^)]*)\)/ ? $1 : undef) || $defaults->{standard};
+
+	my $pattern  = $dt_format{$kind}
 		or return "dt format $kind not known";
 
 	my $stamp = $value =~ /\D/ ? str2time($value) : $value;
@@ -613,9 +729,75 @@ sub _modif_name($$$)
 	"$args->{varname}$format$value";
 }
 
+sub _modif_chop($$$)
+{	my ($self, $format, $value, $args) = @_;
+	defined $value && length $value or return undef;
+	$format =~ m/^ CHOP\( ([0-9]+) \,? ([^)]+)? \) | CHOP\b /x or die $format;
+
+	my $defaults = $self->defaults('CHOP');
+	my ($width, $units) = ($1 // $defaults->{width}, $2 // $defaults->{units});
+	$width != 0 or return $value;
+
+	# max width of a char is 2
+	return $value if 2 * length $value < $width;    # surely small enough?
+
+	my $v = Unicode::GCString->new(is_utf8($value) ? $value : decode(latin1 => $value));
+	return $value if $width >= $v->columns;          # small enough after counting
+
+	my $head = $defaults->{head};
+	my $tail = $defaults->{tail};
+
+	#XXX This is expensive for long texts, but the value could be filled with many zero-widths
+	my ($shortened, $append) = (0, $head . '+0' . $units . $tail);
+	while($v->columns > $width - length $append)
+	{	my $chopped = $v->substr(-1, 1, '');
+
+		unless($chopped->length)
+		{	# nothing left
+			$append = $head . $shortened . $units . $tail;
+			last;
+		}
+
+		$chopped->columns > 0 or next;
+		$shortened++;
+		$append     = $head . '+' . $shortened . $units . $tail;
+	}
+
+	# might be one column short
+	my $pad = $v->columns < $width - (length $append) ? ' ' : '';
+	$v->as_string . $pad . $append;
+}
+
+sub _modif_ellipsis($$$)
+{	my ($self, $format, $value, $args) = @_;
+	defined $value && length $value or return undef;
+	$format =~ m/^ EL\( ([0-9]+) \,? ([^)]+)? \) | EL\b /x or die $format;
+
+	my $defaults = $self->defaults('EL');
+	my ($width, $replace) = ($1 // $defaults->{width}, $2 // $defaults->{replace});
+	$width != 0 or return $value;
+
+	# max width of a char is 2
+	return $value if 2 * length($value) < $width;    # surely small enough?
+
+	my $v = Unicode::GCString->new(is_utf8($value) ? $value : decode(latin1 => $value));
+	return $value if $width >= $v->columns;          # small enough after counting
+
+	my $r = Unicode::GCString->new(is_utf8($replace) ? $replace : decode(latin1 => $replace));
+	$r->columns < $width or return $replace;
+
+	#XXX This is expensive for long texts, but the value could be filled with many zero-widths
+	my $take = $width - $r->columns;
+	$v->substr(-1, 1, '') while $v->columns > $take;
+
+	# might be one column short
+	my $pad = $v->columns + $r->columns < $width ? ' ' : '';
+	$v->as_string . $pad . $replace;
+}
+
 =function printi [$fh], $format, %data|\%data
-Calls M<sprinti()> to fill the %data into $format, and
-then sends it to the $fh (by default the selected file)
+Calls M<sprinti()> to fill the %data into $format, and then sends it to
+the $fh (by default the selected file handle)
 
   open my $fh, '>:encoding(UTF-8)', $file;
   printi $fh, ...
@@ -631,9 +813,9 @@ sub printi($$@)
 }
 
 
-=function printp [$fh], $format, @params, %options
-Calls M<sprintp()> to fill the @params in $format, and
-then sends it to the $fh (by default the selected file)
+=function printp [$fh], $format, @positionals, %options
+Calls M<sprintp()> to fill the @positionals in $format, and
+then sends it to the $fh (by default the selected file handle).
 =cut
 
 sub printp($$@)
@@ -1001,7 +1183,7 @@ specify its width, then there is no performance penalty for using 'S'.
   # name right aligned, commas on same position, always
   printp "name: {name%20S},\n", name => $some_chinese;
 
-=subsubsection POSIX modifier extensions '%[+ -]?[0-9]*[_,.]d'
+=subsubsection POSIX modifier extensions '%[+ -0]?[0-9]*[_,.]?d'
 
 [0.96] Only available when you print (big) decimals: add an underscore,
 comma, or dot on the thousands.
@@ -1018,6 +1200,19 @@ comma, or dot on the thousands.
   printi "'{v% ,d}'",   v =>  10000;   # ' 10,000';
   printi "'{v% ,d}'",   v => -10000;   # '-10,000';
 
+[1.00] You can set the default C<FORMAT> separator:
+
+  use String::Print
+      defaults => [ FORMAT => { thousands => ',' } ];
+
+  # or
+  my $sp = String::Print->new(
+     defaults => { FORMAT => { thousands => ',' }},
+  );
+
+  # or
+  $sp->setDefaults(FORMAT => { thousands => ',' });
+
 =subsection Modifier: BYTES
 
 [0.91] Too often, you have to translate a (file) size into humanly readible
@@ -1038,24 +1233,32 @@ and " 27 MB".
 little flexible in values they accept, but do not expect miracles: when
 it get harder, you will need to process it yourself.
 
-The actual treatment of a time value depends on the value: three
+The actual treatment of a time value depends on the value.  Four
 different situations:
 
 =over 4
 
 =item 1. numeric
-
 A pure numeric value is considered "seconds since epoch", unless it
 is smaller than 21000000, in which case it is taken as date without
 separators.
 
-=item 2. date format without time-zone
+=item 2. M<DateTime> object
+[1.00] Use a M<DateTime> object to provide the value.  This way, the
+format does not need to know whether the date is specified as object or
+as string.
 
+  my $now = DateTime->now;
+  printi "{t YEAR}", t => $now;  # works for DateTime, epoch and string
+  printi "{t.year YEAR}", t => $now;  # same effect, DateTime only
+  printi "{t.year}", t => $now;  # will also work, not as nice
+
+=item 3. date format without time-zone
 The same formats are understood as in the next option, but without
 time-zone information.  The date is processed as text as if in the
 local time zone, and the output in the local time-zone.
 
-=item 3. date format with time-zone
+=item 4. date format with time-zone
 
 By far not all possible date formats are supported, just a few common
 versions, like
@@ -1068,7 +1271,7 @@ versions, like
   2017-6-1                       # only for YEAR and DATE
   12:34                          # only for TIME
 
-The meaning of 05-04-2017 is unclear, so not supported.  Milliseconds
+The meaning of C<05-04-2017> is ambiguous, so not supported.  Milliseconds
 get ignored.
 
 When the provided value has a timezone indication, it will get
@@ -1079,8 +1282,7 @@ converted into the local timezone of the observer.
 The output of C<YEAR> is in format 'YYYY', for C<DATE> it will always be
 'YYYY-MM-DD', where C<TIME> produces 'HH:mm:ss'.
 
-The short form C<DT> is an alias for C<DT(FT)>.  The DT modifier can
-produce different formats:
+The DT modifier can produce different formats:
 
   DT(ASC)     : %a %b %e %T %Y       asctime output
   DT(FT)      : %F %T                YYYY-MM-DD HH:MM:SS
@@ -1091,6 +1293,10 @@ produce different formats:
 
 You may suggest additional formats, or add your own modifier.
 
+The defaults are:
+
+  DT => { standard => 'FT' },
+
 =subsection Modifier: //word, //"string", //'string'
 
 [0.91] By default, an undefined value is shown as text 'undef'.  Empty
@@ -1108,13 +1314,56 @@ different kinds of output:
   "price: {price//5 EUR}"
   "price: {price EUR//unknown}"
 
-=subsection Modifier: '='
+=subsection Modifier: '=' (show name)
 
 [0.96] As (always trailing) modifier, this will show the interpolated
 name before the value.  It might simplify debugging statements.
 
-  printi "visitors: {count=}", count => 1;      # visitors: count=1
-  printi "v: {count %-8,d =}X", count => 10000; # v: count=10,000␣␣X
+  "visitors: {count=}", count => 1;      # visitors: count=1
+  "v: {count %-8,d =}X", count => 10000; # v: count=10,000␣␣X
+
+=subsection Modifier: EL, EL($width), or EL($width,$replace)
+
+[1.00] When the string is larger than C<$width> columns, then chop it
+short and add a 'mid-line ellipsis' character: C< ⋯  >.  You may also
+pick another replacement string.   The comma is optional
+
+Attention: "columns" not "characters": it is aware of wide fonts, like
+chinese characters (see C<%S> above).  The default ellipsis is also two
+columns wide.
+
+  "Intro: {text EL(10)}";     # Intro: 12345678⋯ 
+  "Intro: {text EL(10,⋮)}";   # Intro: 123456789⋮ 
+  "Intro: {text EL(10⋮)}";    # Intro: 123456789⋮ 
+  "Intro: {text EL(10,XY)}";  # Intro: 12345678XY 
+  "Intro: {text EL(10XY)}";   # Intro: 12345678XY 
+
+The defaults for EL are '20' and '⋯' (mid-dots).  You can changes these
+with M<setDefaults()>:
+
+  $sp->setDefaults(EL => { width => 10, replace => '⋮' });
+  $sp->printi("Intro: {text EL}"); # Intro: 12345678⋯ 
+
+=subsection Modifier: CHOP, CHOP($width) or CHOP($width,$units)
+
+[1.00] When the string is larger than C<$width> columns (defaults to
+20), then chop it short and add C<< [+42] >>: the number of character
+chopped off.  The C<$width> is the size of the result string.
+The comma is optional.
+
+  "Intro: {text CHOP(10)}";        # Intro: 12345[+42]
+  "Intro: {text CHOP(19 chars)}";  # Intro: 1234578[+33 chars]
+  "Intro: {text CHOP(19, chars)}"; # Intro: 1234578[+33 chars]
+
+The same effect can be reached by setting the defaults
+
+  $sp->setDefaults(CHOP => +{width => 19, units => ' chars'});
+  $sp->printi("Intro: {text CHOP}", text => $t); # Intro: 1234578[+33 chars]
+
+Other defaults are C<head> (C<<[>>) and C<tail> (C<<]>>).
+
+  $sp->setDefaults(CHOP => +{head => '«', tail => '»'});
+  $sp->printi("Intro: {text CHOP}", text => $t); # Intro: 1234578«+12»
 
 =subsection Private modifiers
 
@@ -1257,7 +1506,7 @@ Better not to have HTML in your program: leave it to the template.  But
 in some cases, you have no choice.
 
 
-=section Compared to other modules on CPAN
+=section String::Print Compared to other modules on CPAN
 
 There are a quite a number of modules on CPAN which extend the functionality
 of C<printf()>.  To name a few:
